@@ -20,6 +20,9 @@
 
 #include "includes.h"
 #include "libnet/libnet.h"
+#include "libcli/auth/libcli_auth.h"
+#include "../librpc/gen_ndr/cli_samr.h"
+#include "../librpc/gen_ndr/cli_lsa.h"
 
 /****************************************************************
 ****************************************************************/
@@ -263,7 +266,13 @@ static ADS_STATUS libnet_unjoin_remove_machine_acct(TALLOC_CTX *mem_ctx,
 	ADS_STATUS status;
 
 	if (!r->in.ads) {
-		return libnet_unjoin_connect_ads(mem_ctx, r);
+		status = libnet_unjoin_connect_ads(mem_ctx, r);
+		if (!ADS_ERR_OK(status)) {
+			libnet_unjoin_set_error_string(mem_ctx, r,
+				"failed to connect to AD: %s",
+				ads_errstr(status));
+			return status;
+		}
 	}
 
 	status = ads_leave_realm(r->in.ads, r->in.machine_name);
@@ -741,6 +750,56 @@ static NTSTATUS libnet_join_lookup_dc_rpc(TALLOC_CTX *mem_ctx,
 	return status;
 }
 
+/****************************************************************
+ Do the domain join unsecure
+****************************************************************/
+
+static NTSTATUS libnet_join_joindomain_rpc_unsecure(TALLOC_CTX *mem_ctx,
+						    struct libnet_JoinCtx *r,
+						    struct cli_state *cli)
+{
+	struct rpc_pipe_client *pipe_hnd = NULL;
+	unsigned char orig_trust_passwd_hash[16];
+	unsigned char new_trust_passwd_hash[16];
+	fstring trust_passwd;
+	NTSTATUS status;
+
+	status = cli_rpc_pipe_open_noauth(cli, &ndr_table_netlogon.syntax_id,
+					  &pipe_hnd);
+	if (!NT_STATUS_IS_OK(status)) {
+		return status;
+	}
+
+	if (!r->in.machine_password) {
+		r->in.machine_password = generate_random_str(mem_ctx, DEFAULT_TRUST_ACCOUNT_PASSWORD_LENGTH);
+		NT_STATUS_HAVE_NO_MEMORY(r->in.machine_password);
+	}
+
+	E_md4hash(r->in.machine_password, new_trust_passwd_hash);
+
+	/* according to WKSSVC_JOIN_FLAGS_MACHINE_PWD_PASSED */
+	fstrcpy(trust_passwd, r->in.admin_password);
+	strlower_m(trust_passwd);
+
+	/*
+	 * Machine names can be 15 characters, but the max length on
+	 * a password is 14.  --jerry
+	 */
+
+	trust_passwd[14] = '\0';
+
+	E_md4hash(trust_passwd, orig_trust_passwd_hash);
+
+	status = rpccli_netlogon_set_trust_password(pipe_hnd, mem_ctx,
+						    r->in.machine_name,
+						    orig_trust_passwd_hash,
+						    r->in.machine_password,
+						    new_trust_passwd_hash,
+						    r->in.secure_channel_type);
+
+	return status;
+}
+
 /****************************************************************
  Do the domain join
 ****************************************************************/
@@ -767,6 +826,17 @@ static NTSTATUS libnet_join_joindomain_rpc(TALLOC_CTX *mem_ctx,
 	ZERO_STRUCT(domain_pol);
 	ZERO_STRUCT(user_pol);
 
+	switch (r->in.secure_channel_type) {
+	case SEC_CHAN_WKSTA:
+		acct_flags = ACB_WSTRUST;
+		break;
+	case SEC_CHAN_BDC:
+		acct_flags = ACB_SVRTRUST;
+		break;
+	default:
+		return NT_STATUS_INVALID_PARAMETER;
+	}
+
 	if (!r->in.machine_password) {
 		r->in.machine_password = generate_random_str(mem_ctx, DEFAULT_TRUST_ACCOUNT_PASSWORD_LENGTH);
 		NT_STATUS_HAVE_NO_MEMORY(r->in.machine_password);
@@ -818,15 +888,13 @@ static NTSTATUS libnet_join_joindomain_rpc(TALLOC_CTX *mem_ctx,
 			SAMR_USER_ACCESS_SET_ATTRIBUTES;
 		uint32_t access_granted = 0;
 
-		/* Don't try to set any acct_flags flags other than ACB_WSTRUST */
-
 		DEBUG(10,("Creating account with desired access mask: %d\n",
 			access_desired));
 
 		status = rpccli_samr_CreateUser2(pipe_hnd, mem_ctx,
 						 &domain_pol,
 						 &lsa_acct_name,
-						 ACB_WSTRUST,
+						 acct_flags,
 						 access_desired,
 						 &user_pol,
 						 &access_granted,
@@ -1071,8 +1139,8 @@ NTSTATUS libnet_join_ok(const char *netbios_domain_name,
 
 	status = cli_rpc_pipe_open_schannel_with_key(
 		cli, &ndr_table_netlogon.syntax_id, NCACN_NP,
-		PIPE_AUTH_LEVEL_PRIVACY,
-		netbios_domain_name, netlogon_pipe->dc, &pipe_hnd);
+		DCERPC_AUTH_LEVEL_PRIVACY,
+		netbios_domain_name, &netlogon_pipe->dc, &pipe_hnd);
 
 	cli_shutdown(cli);
 
@@ -1524,7 +1592,8 @@ static WERROR libnet_join_post_processing(TALLOC_CTX *mem_ctx,
 	}
 
 #ifdef WITH_ADS
-	if (r->out.domain_is_ad) {
+	if (r->out.domain_is_ad &&
+	    !(r->in.join_flags & WKSSVC_JOIN_FLAGS_JOIN_UNSECURE)) {
 		ADS_STATUS ads_status;
 
 		ads_status  = libnet_join_post_processing_ads(mem_ctx, r);
@@ -1762,7 +1831,7 @@ static WERROR libnet_DomainJoin(TALLOC_CTX *mem_ctx,
 				"failed to find DC for domain %s",
 				r->in.domain_name,
 				get_friendly_nt_error_msg(status));
-			return WERR_DOMAIN_CONTROLLER_NOT_FOUND;
+			return WERR_DCNOTFOUND;
 		}
 
 		dc = strip_hostname(info->dc_unc);
@@ -1784,7 +1853,8 @@ static WERROR libnet_DomainJoin(TALLOC_CTX *mem_ctx,
 	}
 
 #ifdef WITH_ADS
-	if (r->out.domain_is_ad && r->in.account_ou) {
+	if (r->out.domain_is_ad && r->in.account_ou &&
+	    !(r->in.join_flags & WKSSVC_JOIN_FLAGS_JOIN_UNSECURE)) {
 
 		ads_status = libnet_join_connect_ads(mem_ctx, r);
 		if (!ADS_ERR_OK(ads_status)) {
@@ -1804,7 +1874,12 @@ static WERROR libnet_DomainJoin(TALLOC_CTX *mem_ctx,
 	}
 #endif /* WITH_ADS */
 
-	status = libnet_join_joindomain_rpc(mem_ctx, r, cli);
+	if ((r->in.join_flags & WKSSVC_JOIN_FLAGS_JOIN_UNSECURE) &&
+	    (r->in.join_flags & WKSSVC_JOIN_FLAGS_MACHINE_PWD_PASSED)) {
+		status = libnet_join_joindomain_rpc_unsecure(mem_ctx, r, cli);
+	} else {
+		status = libnet_join_joindomain_rpc(mem_ctx, r, cli);
+	}
 	if (!NT_STATUS_IS_OK(status)) {
 		libnet_join_set_error_string(mem_ctx, r,
 			"failed to join domain '%s' over rpc: %s",
@@ -1924,7 +1999,7 @@ static WERROR libnet_DomainUnjoin(TALLOC_CTX *mem_ctx,
 		W_ERROR_HAVE_NO_MEMORY(r->in.domain_sid);
 	}
 
-	if (!(r->in.unjoin_flags & WKSSVC_JOIN_FLAGS_ACCOUNT_DELETE) &&
+	if (!(r->in.unjoin_flags & WKSSVC_JOIN_FLAGS_ACCOUNT_DELETE) && 
 	    !r->in.delete_machine_account) {
 		libnet_join_unjoindomain_remove_secrets(mem_ctx, r);
 		return WERR_OK;
@@ -1947,7 +2022,7 @@ static WERROR libnet_DomainUnjoin(TALLOC_CTX *mem_ctx,
 				"failed to find DC for domain %s",
 				r->in.domain_name,
 				get_friendly_nt_error_msg(status));
-			return WERR_DOMAIN_CONTROLLER_NOT_FOUND;
+			return WERR_DCNOTFOUND;
 		}
 
 		dc = strip_hostname(info->dc_unc);
@@ -1956,19 +2031,19 @@ static WERROR libnet_DomainUnjoin(TALLOC_CTX *mem_ctx,
 	}
 
 #ifdef WITH_ADS
-	/* for net ads leave, try to delete the account.  If it works,
-	   no sense in disabling.  If it fails, we can still try to
+	/* for net ads leave, try to delete the account.  If it works, 
+	   no sense in disabling.  If it fails, we can still try to 
 	   disable it. jmcd */
-
+	   
 	if (r->in.delete_machine_account) {
 		ADS_STATUS ads_status;
 		ads_status = libnet_unjoin_connect_ads(mem_ctx, r);
 		if (ADS_ERR_OK(ads_status)) {
 			/* dirty hack */
-			r->out.dns_domain_name =
+			r->out.dns_domain_name = 
 				talloc_strdup(mem_ctx,
 					      r->in.ads->server.realm);
-			ads_status =
+			ads_status = 
 				libnet_unjoin_remove_machine_acct(mem_ctx, r);
 		}
 		if (!ADS_ERR_OK(ads_status)) {
@@ -1984,7 +2059,7 @@ static WERROR libnet_DomainUnjoin(TALLOC_CTX *mem_ctx,
 	}
 #endif /* WITH_ADS */
 
-	/* The WKSSVC_JOIN_FLAGS_ACCOUNT_DELETE flag really means
+	/* The WKSSVC_JOIN_FLAGS_ACCOUNT_DELETE flag really means 
 	   "disable".  */
 	if (r->in.unjoin_flags & WKSSVC_JOIN_FLAGS_ACCOUNT_DELETE) {
 		status = libnet_join_unjoindomain_rpc(mem_ctx, r);
@@ -1997,11 +2072,11 @@ static WERROR libnet_DomainUnjoin(TALLOC_CTX *mem_ctx,
 			}
 			return ntstatus_to_werror(status);
 		}
-
+		
 		r->out.disabled_machine_account = true;
 	}
 
-	/* If disable succeeded or was not requested at all, we
+	/* If disable succeeded or was not requested at all, we 
 	   should be getting rid of our end of things */
 
 	libnet_join_unjoindomain_remove_secrets(mem_ctx, r);
